snappy: Topology and geometry of 3-manifolds, with a focus on hyperbolic structures
===================================================================================

Description
-----------

Studying the topology and geometry of 3-manifolds, with a focus on hyperbolic structures.

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/snappy/

